@@ -3,6 +3,7 @@ from pathlib import Path
 from importlib.resources import files
 import os, argparse, sys, json, shutil
 from datetime import datetime
+
 from .io import (
     ensure_weights,
     ensure_yolo_yaml,
@@ -12,20 +13,17 @@ from .io import (
 )
 from .val_split import process_labelstudio_project
 
-# ---- Base Paths ----
-BASE_DIR = Path.home() / "YOLO4r"
-BASE_DIR.mkdir(parents=True, exist_ok=True)
-
-LS_ROOT = BASE_DIR / "labelstudio-projects"
-DATA_ROOT = BASE_DIR / "data"
-RUNS_ROOT = BASE_DIR / "runs"
-LOGS_ROOT = BASE_DIR / "logs"
-MODELS_ROOT = BASE_DIR / "models"
-WEIGHTS_ROOT = BASE_DIR / "weights"
-
-# Ensure directories exist
-for d in [LS_ROOT, DATA_ROOT, RUNS_ROOT, LOGS_ROOT, MODELS_ROOT, WEIGHTS_ROOT]:
-    d.mkdir(parents=True, exist_ok=True)
+# ---- CENTRALIZED PATHS (from utils.paths) ----
+from ..paths import (
+    BASE_DIR,
+    DATA_DIR as DATA_ROOT,
+    RUNS_DIR as RUNS_ROOT,
+    LOGS_DIR as LOGS_ROOT,
+    MODELS_DIR as MODELS_ROOT,
+    WEIGHTS_DIR as WEIGHTS_ROOT,
+    LS_ROOT,
+    get_training_paths,
+)
 
 # -------- Example Project + Model Installation --------
 def _install_examples():
@@ -74,19 +72,6 @@ def is_custom_yaml(arch: str, models_dir: Path) -> bool:
 
     return False
 
-def get_training_paths(dataset_folder: Path, test=False):
-    """Return key directory paths for training and logging based on dataset folder."""
-    return {
-        "runs_root": BASE_DIR / "runs" / "test" if test else BASE_DIR / "runs",
-        "logs_root": BASE_DIR / "logs" / "test" if test else BASE_DIR / "logs",
-        "train_folder": dataset_folder / "train/images",
-        "val_folder": dataset_folder / "val/images",
-        "weights_folder": BASE_DIR / "weights",
-        "models_folder": BASE_DIR / "models",
-        "dataset_folder": dataset_folder,
-    }
-
-
 def _find_labelstudio_projects(ls_root: Path):
     """Return list of candidate Label Studio project folders under ls_root."""
     if not ls_root.exists():
@@ -103,7 +88,6 @@ def _find_labelstudio_projects(ls_root: Path):
             candidates.append(p)
     return candidates
 
-
 def _get_dataset_label_mode(dataset_folder: Path) -> str | None:
     """Read label_mode from metadata.json if available."""
     meta_path = dataset_folder / "metadata.json"
@@ -116,12 +100,10 @@ def _get_dataset_label_mode(dataset_folder: Path) -> str | None:
     except Exception:
         return None
 
-
 def _family_is_obb(family: str | None) -> bool:
     """Return True if the given model/arch family is an OBB variant."""
     return bool(family and family.endswith("-obb"))
 
-
 def get_args():
     """Parse and return command-line arguments for YOLO training."""
     parser = argparse.ArgumentParser(description="YOLO Training Script")
